<TS version="2.1" language="bn">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">ঠিকানা বা লেবেল সম্পাদনা করতে ডান-ক্লিক করুন</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">নতুন একটি ঠিকানা তৈরি করুন</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">নতুন</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">বর্তমানে নির্বাচিত ঠিকানাটি সিস্টেম ক্লিপবোর্ডে কপি করুন</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">এবং কপি করুন</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">বন্ধ করুন</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">বাছাইকৃত ঠিকানাটি লিস্ট থেকে মুছুন</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">খুঁজতে ঠিকানা বা লেবেল লিখুন</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">বর্তমান ট্যাবের তথ্যগুলো একটি আলাদা নথিতে লিপিবদ্ধ করুন </translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;মুছুন</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">কয়েন পাঠানোর ঠিকানা বাছাই করুন</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">কয়েন গ্রহণ করার ঠিকানা বাছাই করুন।</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">ঠিকানাগুলো পাঠানো হচ্ছে।</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">ঠিকানাগুলো গ্রহণ করা হচ্ছে।</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">পেমেন্ট পাওয়ার জন্য এটি আপনার বিটকয়েন ঠিকানা। নতুন ঠিকানা তৈরী করতে "নতুন গ্রহণের ঠিকানা তৈরী করুন" বোতাম ব্যবহার করুন। সাইন ইন করা শুধুমাত্র "উত্তরাধিকার" ঠিকানার মাধ্যমেই সম্ভব।</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">কমা দিয়ে আলাদা করা ফাইল</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">টিকেট</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ঠিকানা</translation>
    </message>
    </context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">1%1 সেটিংস ফাইল টি সম্ভবত নষ্ট বা করাপ্ট</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">পলাতক ব্যতিক্রম</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">একটি মারাত্মক ত্রুটি ঘটেছে।%1 নিরাপদে চলতে পারবেনা এবং প্রস্থান করবে</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">অভ্যন্তরীণ ত্রুটি</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">একটি অভ্যন্তরীণ ত্রুটি ঘটেছে। %1 নিরাপদে চালিয়ে যাওয়ার চেষ্টা করবে। এটি একটি অপ্রত্যাশিত বাগ যা নীচের বর্ণনা অনুযায়ী রিপোর্ট করা যেতে পারে৷</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">আপনি কি ডিফল্ট মানগুলিতে সেটিংস রিসেট করতে চান, নাকি পরিবর্তন না করেই বাতিল করতে চান?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">একটি জটিল ত্রুটি হয়েছে। সেটিং ফাইল টি রাইটেবল কিনা চেক করুন, অথবা -nosettings দিয়ে রান করার চেষ্টা করুন</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 এখনো নিরাপদে বের হয়নি</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An inbound connection from a peer. An inbound connection is a connection initiated by a peer.</extracomment>
        <translation type="unfinished">অন্তর্মুখী</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An outbound connection to a peer. An outbound connection is a connection initiated by us.</extracomment>
        <translation type="unfinished">বহির্গামী</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">একটি নতুন ওয়ালেট তৈরি করুন</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">ছোট করুন</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;বিকল্প...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;ওয়ালেট এনক্রিপ্ট করুন...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">ওয়ালেট বন্ধ করুন...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">ওয়ালেট তৈরী করুন...</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">সব ওয়ালেট গুলো বন্ধ করুন...</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">শিরোনাম সিঙ্ক করা হচ্ছে (%1%)...</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">নেটওয়ার্কের সাথে সিঙ্ক্রোনাইজ করা হচ্ছে...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">ডিস্ক এ ব্লকস ইনডেক্স করা হচ্ছে...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">ডিস্কে ব্লক প্রসেস করা হচ্ছে...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">সহকর্মীদের সাথে সংযোগ করা হচ্ছে...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">আংশিক স্বাক্ষরিত বিটকয়েন লেনদেন লোড করুন</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">ক্লিপবোর্ড থেকে আংশিক স্বাক্ষরিত বিটকয়েন লেনদেন লোড করুন</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">সব ওয়ালেটগুলি  বন্ধ করুন</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">অক্ষরগুলি আড়াল করুন </translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">ওভারভিউ ট্যাবে মানগুলি আড়াল করুন</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">আরো কর্মের জন্য চাপ দিন</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">নেটওয়ার্ক কার্যকলাপ বন্ধ করুন</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">নেটওয়ার্ক কার্যকলাপ চালু করুন</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">লেনদেন পাঠানো হয়েছে</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">লেনদেন আসছে</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">আসল বার্তা:</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">পরিমাণ দেখানোর জন্য একক। অন্য একক নির্বাচন করতে ক্লিক করুন।</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">মুদ্রা নির্বাচন</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">পরিমাণ</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">পারিশ্রমিক</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">পরিবর্তন</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">তারিখ</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">নিশ্চিত করা হয়েছে</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">ঠিকানা কপি করুন</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">কপি লেবেল</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">কপি পরিমাণ</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">লেনদেন আইডি এবং আউটপুট সূচক কপি করুন</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Are you sure you wish to close the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">আপনি কি নিশ্চিত যে আপনি ওয়ালেট বন্ধ করতে চান&lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
    <message>
        <source>Closing the wallet for too long can result in having to resync the entire chain if pruning is enabled.</source>
        <translation type="unfinished">ওয়ালেটটি অনেকক্ষণ বন্ধ করার ফলে পুনঃসুসংগত করতে পুরো চেইনটি পুনরায় সিঙ্ক করতে হতে পারে।</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">সব ওয়ালেটগুলি  বন্ধ করুন</translation>
    </message>
    <message>
        <source>Are you sure you wish to close all wallets?</source>
        <translation type="unfinished">আপনি কি নিশ্চিত যে আপনি সমস্ত ওয়ালেট বন্ধ করতে চান?</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">উন্নত বিকল্প </translation>
    </message>
    <message>
        <source>Use descriptors for scriptPubKey management</source>
        <translation type="unfinished">ScriptPub-এর জন্য বর্ণনাকারীর ব্যবস্থা করুন 
 </translation>
    </message>
    <message>
        <source>Descriptor Wallet</source>
        <translation type="unfinished">বর্ণনাকারী ওয়ালেট </translation>
    </message>
    <message>
        <source>Compiled without sqlite support (required for descriptor wallets)</source>
        <translation type="unfinished">sqlite সমর্থন ছাড়াই সংকলিত (বরণাকারী  ওয়ালেটের জন্য প্রয়োজনীয়)</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform>(of %n GB needed)</numerusform>
            <numerusform>(of %n GB needed)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform>(%n GB needed for full chain)</numerusform>
            <numerusform>(%n GB needed for full chain)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">ঠিকানা</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">টাইপ</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An Inbound Connection from a Peer.</extracomment>
        <translation type="unfinished">অন্তর্মুখী</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An Outbound Connection to a Peer.</extracomment>
        <translation type="unfinished">বহির্গামী</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">ঠিকানা কপি করুন</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">অজানা</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;পরিমাণঃ</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;লেবেলঃ</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">&amp;বার্তাঃ</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">ঠিকানা কপি করুন</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">কপি লেবেল</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">কপি পরিমাণ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">তারিখ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">টিকেট</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">পরিমাণ</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">পারিশ্রমিক</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">পরিবর্তন</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;লেবেলঃ</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">তারিখ</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">তারিখ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">টাইপ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">টিকেট</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">ঠিকানা কপি করুন</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">কপি লেবেল</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">কপি পরিমাণ</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">কমা দিয়ে আলাদা করা ফাইল</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">নিশ্চিত করা হয়েছে</translation>
    </message>
    <message>
        <source>Watch-only</source>
        <translation type="unfinished">শুধুমাত্র দেখার জন্য</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">তারিখ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">টাইপ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">টিকেট</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ঠিকানা</translation>
    </message>
    <message>
        <source>ID</source>
        <translation type="unfinished">আইডি</translation>
    </message>
    <message>
        <source>Exporting Successful</source>
        <translation type="unfinished">রপ্তানি সফল হয়েছে</translation>
    </message>
    <message>
        <source>The transaction history was successfully saved to %1.</source>
        <translation type="unfinished">লেনদেনের ইতিহাস সফলভাবে %1 এ সংরক্ষিত হয়েছে।</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished">পরিসীমাঃ</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished">প্রতি</translation>
    </message>
</context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">একটি নতুন ওয়ালেট তৈরি করুন</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">বর্তমান ট্যাবের তথ্যগুলো একটি আলাদা নথিতে লিপিবদ্ধ করুন </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>SQLiteDatabase: Unexpected application id. Expected %u, got %u</source>
        <translation type="unfinished">এস. কিয়ু. লাইট ডাটাবেস : অপ্রত্যাশিত এপ্লিকেশন আই.ডি. প্রত্যাশিত %u, পাওয়া গেলো %u </translation>
    </message>
    <message>
        <source>Starting network threads…</source>
        <translation type="unfinished">নেটওয়ার্ক থ্রেড শুরু হচ্ছে...</translation>
    </message>
    <message>
        <source>The specified config file %s does not exist</source>
        <translation type="unfinished">নির্দিষ্ট কনফিগ ফাইল %s এর অস্তিত্ব নেই</translation>
    </message>
    <message>
        <source>Unable to open %s for writing</source>
        <translation type="unfinished">লেখার জন্যে %s খোলা যাচ্ছে না</translation>
    </message>
    <message>
        <source>Unknown new rules activated (versionbit %i)</source>
        <translation type="unfinished">অজানা নতুন নিয়ম সক্রিয় হলো (ভার্শনবিট %i)</translation>
    </message>
    <message>
        <source>Verifying blocks…</source>
        <translation type="unfinished">ব্লকস যাচাই করা হচ্ছে...</translation>
    </message>
    <message>
        <source>Verifying wallet(s)…</source>
        <translation type="unfinished">ওয়ালেট(স) যাচাই করা হচ্ছে...</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">Settingsসেটিংস ফাইল পড়া যাবে না।fileসেটিংস ফাইল পড়া যাবে না।couldসেটিংস ফাইল পড়া যাবে না।notসেটিংস ফাইল পড়া যাবে না।beসেটিংস ফাইল পড়া যাবে না।read</translation>
    </message>
    </context>
</TS>